aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-isns.c
diff options
context:
space:
mode:
authorRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-21 04:49:01 +0000
committerRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-21 04:49:01 +0000
commitfeab79e32878302a87c7d22c52a2d5a255dbd3e9 (patch)
tree934f82dcbdd30f8c04d96b4215dbb0a6b8bc437e /epan/dissectors/packet-isns.c
parent58a0b106989d8278670d78fba86dd4585c3be52d (diff)
change a whole bunch of ethereal into wireshark
svn path=/trunk/; revision=18196
Diffstat (limited to 'epan/dissectors/packet-isns.c')
-rw-r--r--epan/dissectors/packet-isns.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-isns.c b/epan/dissectors/packet-isns.c
index c65cc50465..e5183a8b66 100644
--- a/epan/dissectors/packet-isns.c
+++ b/epan/dissectors/packet-isns.c
@@ -10,8 +10,8 @@
*
* $Id$
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
@@ -1439,7 +1439,7 @@ AddAttribute(packet_info *pinfo, tvbuff_t *tvb, proto_tree *tree, guint offset,
/* Register the protocol with Ethereal */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.
@@ -1697,7 +1697,7 @@ void proto_register_isns(void)
{ &hf_isns_not_decoded_yet,
{ "Not Decoded Yet","isns.not_decoded_yet",
FT_NONE, BASE_NONE, NULL,0,
- "This tag is not yet decoded by ethereal" ,HFILL}
+ "This tag is not yet decoded by wireshark" ,HFILL}
},
{ &hf_isns_heartbeat_ipv6_addr,
@@ -10,8 +10,8 @@
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*
@@ -1439,7 +1439,7 @@ AddAttribute(packet_info *pinfo, tvbuff_t *tvb, proto_tree *tree, guint offset,
* This program is free software; you can redistribute it and/or
-/* Register the protocol with Ethereal */
+/* Register the protocol with Wireshark */
/* this format is require because a script is used to build the C function
that calls all the protocol registration.